@@ -10,4 +10,10 @@ for function in __all__:
     if function != "main":
         print(function, namespace[function]())
 
-exit(0)
\ No newline at end of file
+def test():
+    try:
+        a
+    except Exception as e:
+        raise NameError("test") from e
+
+test() # exit with code 127 (cause: NameError in test())
